# Class Reference

This is the main python binding for chardetng, a rust character encoding detector for
legacy Web content.

The class here is a wrapper around the rust struct `EncodingDetector`. The documentation
for the rust structure is available on [docs.rs](https://docs.rs/chardetng/).

For more information about the overall function of the library, read Henri Sivonen's
[excellent write-up](https://hsivonen.fi/chardetng/).

## chardetng_py.detector

```{eval-rst}
.. automodule:: chardetng_py.detector
   :members:
   :undoc-members:
```
